import axios from "axios"
import store from '@/store';


const feature_type = {
  namespaced: true,
  state: {
    form: null,
    colorsStyleList: [],
    customForms: [],
    current_feature_type_slug: null,
    feature_types: [],
  },
  mutations: {
    SET_FEATURE_TYPES(state, feature_types) {
      state.feature_types = feature_types;
    },
    SET_CURRENT_FEATURE_TYPE_SLUG(state, payload) {
      state.current_feature_type_slug = payload;
    },
    UPDATE_FORM(state, payload) {
      state.form = payload;
    },
    ADD_CUSTOM_FORM(state, dataKey) {
      state.customForms = [...state.customForms, { dataKey }];
    },
    UPDATE_CUSTOM_FORM(state, payload) {
      const index = state.customForms.findIndex((el) => el.dataKey === payload.dataKey);
      if (index !== -1) state.customForms[index] = payload
    },
    REMOVE_CUSTOM_FORM(state, payload) {
      state.customForms = state.customForms.filter(form => form.dataKey !== payload);
    },
    UPDATE_COLOR_STYLE(state) { // * un peu dirty (mais pas quick) car getter pas réactif avec nested et compliqué de faire dans composants enfants multiples
      let res = [];
      for (let form of state.customForms) {
        if (form.label) res.push(form);
      }
      state.colorsStyleList = res;
    }
  },
  getters: {
    feature_type: state => state.feature_types.find(
      (el) => el.slug === state.current_feature_type_slug
    )
  },
  actions: {

    POST_FEATURE_TYPE({ state }) {
      const data = { form: state.form, formset: state.customForms }
      console.log("data", data)

      axios
        .post(`${process.env.VUE_APP_DJANGO_API_BASE}feature_type/`, data)
        .then((response) => {
          const routerHistory = this.$router.options.routerHistory
          store.commit("SET_USER", response.data.user);
          this.$router.push(routerHistory[routerHistory.length - 1] || "/")
          store.dispatch("GET_USER_LEVEL_PROJECTS");
        })
        .catch(() => {
          store.commit("SET_USER", false)
        });
    },
  },

}

export default feature_type